﻿using HeuristicLab.Services.Authentication.DataAccess;
using HeuristicLab.Services.Authentication.DataTransfer;

namespace HeuristicLab.Services.Authentication
{
    public class Convert
    {

        #region User

        /// <summary>
        /// converts data transfer object to data access objet
        /// </summary>
        /// <param name="source">data transfer object</param>
        /// <returns>data access object</returns>
        public static aspnet_User ToEntity(User source)
        {
            if (source == null) return null;
            return new aspnet_User()
            {
                ApplicationId = source.ApplicationId,
                UserId = source.UserId,
                UserName = source.UserName,
                LoweredUserName = source.LoweredUserName,
                IsAnonymous = source.IsAnonymous,
                LastActivityDate = source.LastActivityDate
            };
        }

        /// <summary>
        /// converts data access object to data transfer object
        /// </summary>
        /// <param name="source">data access object</param>
        /// <returns>data transfer object</returns>
        public static User ToDataTransfer(aspnet_User source)
        {
            if (source == null) return null;
            return new User()
            {
                ApplicationId = source.ApplicationId,
                UserId = source.UserId,
                UserName = source.UserName,
                LoweredUserName = source.LoweredUserName,
                IsAnonymous = source.IsAnonymous,
                LastActivityDate = source.LastActivityDate
            };
        }

        /// <summary>
        /// converts data transfer object to data access object
        /// </summary>
        /// <param name="source">data transfer object</param>
        /// <param name="target">data access object</param>
        public static void ToEntity(User source, aspnet_User target)
        {
            if ((source != null) && (target != null))
            {
                target.ApplicationId = source.ApplicationId;
                target.UserId = source.UserId;
                target.UserName = source.UserName;
                target.LoweredUserName = source.LoweredUserName;
                target.IsAnonymous = source.IsAnonymous;
                target.LastActivityDate = source.LastActivityDate;
            }

        }


        #endregion

        #region Application

        /// <summary>
        /// converts data transfer object to data access objet
        /// </summary>
        /// <param name="source">data transfer object</param>
        /// <returns>data access object</returns>
        public static aspnet_Application ToEntity(Application source)
        {
            if (source == null) return null;
            return new aspnet_Application()
            {
                ApplicationId = source.ApplicationId,
                ApplicationName = source.ApplicationName,
                LoweredApplicationName = source.LoweredApplicationName,
                Description = source.Description
            };
        }

        /// <summary>
        /// converts data access object to data transfer object
        /// </summary>
        /// <param name="source">data access object</param>
        /// <returns>data transfer object</returns>
        public static Application ToDataTransfer(aspnet_Application source)
        {
            if (source == null) return null;
            return new Application()
            {
                ApplicationId = source.ApplicationId,
                ApplicationName = source.ApplicationName,
                LoweredApplicationName = source.LoweredApplicationName,
                Description = source.Description
            };
        }

        /// <summary>
        /// converts data transfer object to data access object
        /// </summary>
        /// <param name="source">data transfer object</param>
        /// <param name="target">data access object</param>
        public static void ToEntity(Application source, aspnet_Application target)
        {
            if ((source != null) && (target != null))
            {
                target.ApplicationId = source.ApplicationId;
                target.ApplicationName = source.ApplicationName;
                target.LoweredApplicationName = source.LoweredApplicationName;
                target.Description = source.Description;
            }

        }

        #endregion

        #region Membership

        /// <summary>
        /// converts data transfer object to data access objet
        /// </summary>
        /// <param name="source">data transfer object</param>
        /// <returns>data access object</returns>
        public static aspnet_Membership ToEntity(Membership source)
        {
            if (source == null) return null;
            return new aspnet_Membership()
            {
                ApplicationId = source.ApplicationId,
                UserId = source.UserId,
                Password = source.Password,
                Email = source.Email,
                LoweredEmail = source.LoweredEmail,
                IsApproved = source.IsApproved,
                IsLockedOut = source.IsLockedOut,
                CreateDate = source.CreateDate,
                LastLoginDate = source.LastLoginDate,
                LastPasswordChangedDate = source.LastPasswordChangedDate,
                LastLockoutDate = source.LastLockoutDate,
                Comment = source.Comment

            };
        }

        /// <summary>
        /// converts data access object to data transfer object
        /// </summary>
        /// <param name="source">data access object</param>
        /// <returns>data transfer object</returns>
        public static Membership ToDataTransfer(aspnet_Membership source)
        {
            if (source == null) return null;
            return new Membership()
            {
                ApplicationId = source.ApplicationId,
                UserId = source.UserId,
                Password = source.Password,
                Email = source.Email,
                LoweredEmail = source.LoweredEmail,
                IsApproved = source.IsApproved,
                IsLockedOut = source.IsLockedOut,
                CreateDate = source.CreateDate,
                LastLoginDate = source.LastLoginDate,
                LastPasswordChangedDate = source.LastPasswordChangedDate,
                LastLockoutDate = source.LastLockoutDate,
                Comment = source.Comment
            };
        }

        /// <summary>
        /// converts data transfer object to data access object
        /// </summary>
        /// <param name="source">data transfer object</param>
        /// <param name="target">data access object</param>
        public static void ToEntity(Membership source, aspnet_Membership target)
        {
            if ((source != null) && (target != null))
            {
                target.ApplicationId = source.ApplicationId;
                target.UserId = source.UserId;
                target.Password = source.Password;
                target.Email = source.Email;
                target.LoweredEmail = source.LoweredEmail;
                target.IsApproved = source.IsApproved;
                target.IsLockedOut = source.IsLockedOut;
                target.CreateDate = source.CreateDate;
                target.LastLoginDate = source.LastLoginDate;
                target.LastPasswordChangedDate = source.LastPasswordChangedDate;
                target.LastLockoutDate = source.LastLockoutDate;
                target.Comment = source.Comment;
            }

        }

        #endregion

        #region Role

        /// <summary>
        /// converts data transfer object to data access objet
        /// </summary>
        /// <param name="source">data transfer object</param>
        /// <returns>data access object</returns>
        public static aspnet_Role ToEntity(Role source)
        {
            if (source == null) return null;
            return new aspnet_Role()
            {
                ApplicationId = source.ApplicationId,
                RoleId = source.RoleId,
                RoleName = source.RoleName,
                LoweredRoleName = source.LoweredRoleName,
                Description = source.Description
            };
        }

        /// <summary>
        /// converts data access object to data transfer object
        /// </summary>
        /// <param name="source">data access object</param>
        /// <returns>data transfer object</returns>
        public static Role ToDataTransfer(aspnet_Role source)
        {
            if (source == null) return null;
            return new Role()
            {
                ApplicationId = source.ApplicationId,
                RoleId = source.RoleId,
                RoleName = source.RoleName,
                LoweredRoleName = source.LoweredRoleName,
                Description = source.Description
            };
        }

        /// <summary>
        /// converts data transfer object to data access object
        /// </summary>
        /// <param name="source">data transfer object</param>
        /// <param name="target">data access object</param>
        public static void ToEntity(Role source, aspnet_Role target)
        {
            if ((source != null) && (target != null))
            {
                target.ApplicationId = source.ApplicationId;
                target.RoleId = source.RoleId;
                target.RoleName = source.RoleName;
                target.LoweredRoleName = source.LoweredRoleName;
                target.Description = source.Description;
            }

        }

        #endregion

    }
}
